[Scummvm-cvs-logs] SF.net SVN: scummvm:[39453] scummvm/trunk/engines/cine

buddha_ at users.sourceforge.net buddha_ at users.sourceforge.net
Mon Mar 16 21:57:17 CET 2009


Revision: 39453
          http://scummvm.svn.sourceforge.net/scummvm/?rev=39453&view=rev
Author:   buddha_
Date:     2009-03-16 20:57:17 +0000 (Mon, 16 Mar 2009)

Log Message:
-----------
Prefix Cine's endian types with CINE_ so they don't clash with already defined LITTLE_ENDIAN and/or BIG_ENDIAN on some platforms.

Modified Paths:
--------------
    scummvm/trunk/engines/cine/pal.cpp
    scummvm/trunk/engines/cine/pal.h

Modified: scummvm/trunk/engines/cine/pal.cpp
===================================================================
--- scummvm/trunk/engines/cine/pal.cpp	2009-03-16 20:24:28 UTC (rev 39452)
+++ scummvm/trunk/engines/cine/pal.cpp	2009-03-16 20:57:17 UTC (rev 39453)
@@ -171,11 +171,11 @@
 
 /*! \brief Is given endian type big endian? (Handles native endian type too, otherwise this would be trivial). */
 bool isBigEndian(const EndianType endianType) {
-	assert(endianType == NATIVE_ENDIAN || endianType == LITTLE_ENDIAN || endianType == BIG_ENDIAN);
+	assert(endianType == CINE_NATIVE_ENDIAN || endianType == CINE_LITTLE_ENDIAN || endianType == CINE_BIG_ENDIAN);
 
 	// Handle explicit little and big endian types here
-	if (endianType != NATIVE_ENDIAN) {
-		return (endianType == BIG_ENDIAN);
+	if (endianType != CINE_NATIVE_ENDIAN) {
+		return (endianType == CINE_BIG_ENDIAN);
 	}
 
 	// Handle native endian type here
@@ -212,7 +212,7 @@
 }
 
 const EndianType Palette::endianType() const {
-	return (_bigEndian ? BIG_ENDIAN : LITTLE_ENDIAN);
+	return (_bigEndian ? CINE_BIG_ENDIAN : CINE_LITTLE_ENDIAN);
 }
 
 Graphics::PixelFormat Palette::colorFormat() const {

Modified: scummvm/trunk/engines/cine/pal.h
===================================================================
--- scummvm/trunk/engines/cine/pal.h	2009-03-16 20:24:28 UTC (rev 39452)
+++ scummvm/trunk/engines/cine/pal.h	2009-03-16 20:57:17 UTC (rev 39453)
@@ -41,11 +41,14 @@
 
 /*! \brief Endian types. Used at least by Palette class's load and save functions.
  * TODO: Move somewhere more general as this is definitely not Cine-engine specific
+ *
+ * NOTE: It seems LITTLE_ENDIAN and/or BIG_ENDIAN were defined already on some platforms so
+ * therefore renamed the enumerations to something not clashing by giving them "CINE_"-prefixes.
  */
 enum EndianType {
-	NATIVE_ENDIAN,
-	LITTLE_ENDIAN,
-	BIG_ENDIAN
+	CINE_NATIVE_ENDIAN,
+	CINE_LITTLE_ENDIAN,
+	CINE_BIG_ENDIAN
 };
 
 struct PalEntry {
@@ -111,7 +114,7 @@
 	uint colorCount() const;
 
 	/*! \brief The original endian type in which this palette was loaded.
 	 * \note This will always return either BIG_ENDIAN or LITTLE_ENDIAN (So no NATIVE_ENDIAN).
 	 */
 	const EndianType endianType() const;
 
@@ -111,7 +114,7 @@
 
 	/*! \brief The original endian type in which this palette was loaded.
-	 * \note This will always return either BIG_ENDIAN or LITTLE_ENDIAN (So no NATIVE_ENDIAN).
+	 * \note This will always return either CINE_BIG_ENDIAN or CINE_LITTLE_ENDIAN (So no CINE_NATIVE_ENDIAN).
 	 */
 	const EndianType endianType() const;


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list